

*** Data analysis for "Monetary Incentives Increase COVID-19 Vaccinations"

clear

use "data_analysis\data_analysis.dta", clear



****** Creating figures for the main text

* Figure 1

global rcap_opt_main xtitle("")  ylabel(65(5)85,labsize(vlarge) angle(360) labgap(1.5) nogrid)  legend(off) lcolor(gs10) lwidth(medium)

global statsby_comm statsby mean=r(mean) ub=r(ub) lb=r(lb) N=r(N)
global conf_int level(90)
global twoway_bar_opt  lwidth(none) barw(0.75) graphregion(color(white)) 
global treatment_label_inc xlabel(1 `""{bf:Incentives}" "Condition""' 0 `""{bf:Control}" "Condition""' , labsize(large) labgap(4) noticks)

preserve
recode treatment (5=0) (0=1) (1=2) (2=3) (3=4) (4=5) 
keep if treatment == 0 | treatment == 1
tab treatment
$statsby_comm $sample, by(treatment) clear: ci mean $behavior1, $conf_int
gen round_mean = round(mean,0.1)
gen mean_label = string(round_mean, "%2.0f")
replace mean_label = mean_label+"%"
twoway (bar mean treatment if treatment == 0, $twoway_bar_opt fcolor(gs3) fintensity(inten80)) ///
(bar mean treatment if treatment == 1, $twoway_bar_opt  fcolor(dkgreen) fintensity(inten90)) ///
 (bar mean treatment if treatment == 2, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
(scatter round_mean treatment, msymbol(none) mlabel(mean_label) mlabsize(vlarge) mlabgap(35pt) mlabposition(12)) ///
(rcap ub lb treatment, title("{bf:Vaccination Uptake (%)}", size(large) height(8) position(11) color(black)) $rcap_opt_main $treatment_label_inc )  , name(inc_1, replace)
restore


global rcap_opt_main xtitle("")  ylabel(75(5)95,labsize(vlarge) angle(360) labgap(1.5) nogrid)  legend(off) lcolor(gs10) lwidth(medium)

global statsby_comm statsby mean=r(mean) ub=r(ub) lb=r(lb) N=r(N)
global conf_int level(90)
global twoway_bar_opt  lwidth(none) barw(0.75) graphregion(color(white)) 
global treatment_label_inc xlabel(1 `""{bf:Incentives}" "Condition""' 0 `""{bf:Control}" "Condition""' , labsize(large) labgap(4) noticks)


preserve
recode treatment (5=0) (0=1) (1=2) (2=3) (3=4) (4=5) 
keep if treatment == 0 | treatment == 1
$statsby_comm $sample, by(treatment) clear: ci mean $intention1, $conf_int
gen round_mean = round(mean,0.1)
gen mean_label = string(round_mean, "%2.0f")
replace mean_label = mean_label+"%"
twoway (bar mean treatment if treatment == 0, $twoway_bar_opt fcolor(gs3) fintensity(inten80)) ///
(bar mean treatment if treatment == 1, $twoway_bar_opt  fcolor(dkgreen) fintensity(inten90)) ///
 (bar mean treatment if treatment == 2, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
(scatter round_mean treatment, msymbol(none) mlabel(mean_label) mlabsize(vlarge) mlabgap(35pt) mlabposition(12)) ///
(rcap ub lb treatment, title("{bf:Intentions to Vaccinate (%)}", size(large) height(8) position(11) color(black)) $rcap_opt_main $treatment_label_inc ) , name(inc_2, replace)
restore

graph combine inc_1 inc_2

graph export "$export/main_effects_incentives.pdf", as(pdf) replace
graph export "$export/main_effects_incentives.png", as(png) replace





* Figure 2 (labels were made nicer in adobe acrobat)
est clear

reg		vaccinated $treatments  $pap_contr $sample , robust
estimates store vaccinated_est_pay 

reg		intention1 $treatments $pap_contr $sample  , robust
estimates store intention1_est_pay 

eststo:    		reg		$behavior1 treat_pay nudge treat_min $pap_contr $sample, robust
estimates store vaccinated_est_nudge

eststo:    		reg		$intention1 treat_pay nudge treat_min $pap_contr $sample, robust
estimates store intention1_est_nudge

foreach i in soc arg info min {
reg		vaccinated $treatments  $pap_contr $sample , robust
estimates store vaccinated_est_`i'

reg		intention1 $treatments $pap_contr $sample  , robust
estimates store intention1_est_`i'
}

global msizeopt small

global inc_opts mcolor($incentivecolor)  ciopts(lcolor($incentivecolor) msize($msizeopt) lwidth(medium)) msymbol(circle)
global int_opts mcolor($incentivecolor%40) ciopts(lcolor($incentivecolor%40) msize($msizeopt) lwidth(medium)) msymbol(circle_hollow) 


global nudge1_inc_opts mcolor($nudgecolor)  ciopts(lcolor($nudgecolor) msize($msizeopt) lwidth(medium)) msymbol(circle)
global nudge1_int_opts mcolor($nudgecolor%40) ciopts(lcolor($nudgecolor%40) msize($msizeopt) lwidth(medium)) msymbol(circle_hollow) 

global nudge_inc_opts mcolor($nudgecolor)  ciopts(lcolor($nudgecolor) msize($msizeopt) lwidth(medium)) msymbol(circle)
global nudge_int_opts mcolor($nudgecolor%40) ciopts(lcolor($nudgecolor%40) msize($msizeopt) lwidth(medium)) msymbol(circle_hollow) 


global min_inc_opts mcolor($remindercolor)  ciopts(lcolor($remindercolor) msize($msizeopt) lwidth(medium)) msymbol(circle)
global min_int_opts mcolor($remindercolor%40) ciopts(lcolor($remindercolor%60) msize($msizeopt) lwidth(medium)) msymbol(circle_hollow) 


global none_opts mcolor(white%0)  ciopts(lcolor(white%0) msize($msizeopt) lwidth(medium)) msymbol(circle)

graph set window fontface "Arial"

coefplot ( vaccinated_est_pay  , aseq(Incentives Condition) $inc_opts keep(treat_pay) )  ///
 (intention1_est_pay  , aseq(Incentives: Intentions) $int_opts keep(treat_pay) ) ///
 ( vaccinated_est_nudge  , aseq(All Nudge Conditions) $nudge1_inc_opts keep(nudge))  ///
  ( intention1_est_nudge  , aseq(All Nudges: Intentions) $nudge1_int_opts keep(nudge))  ///
  (intention1_est_pay  , aseq(NOT 1) $none_opts keep(treat_pay) ) ///
 ( vaccinated_est_soc , aseq(Social Impact Condition) $nudge_inc_opts keep(treat_soc))  ///
  ( intention1_est_soc  , aseq(Social Impact: Intentions)  $nudge_int_opts keep(treat_soc))  ///
   ( vaccinated_est_arg  , aseq(Argument Condition) $nudge_inc_opts keep(treat_arg) )  ///
  ( intention1_est_arg , aseq(Arguments: Intentions)  $nudge_int_opts keep(treat_arg))  ///
   ( vaccinated_est_info  , aseq(Information Condition) $nudge_inc_opts keep(treat_info))  ///
  ( intention1_est_info  , aseq(Information: Intentions)  $nudge_int_opts keep(treat_info))  ///
    (intention1_est_pay  , aseq(NOT2) $none_opts keep(treat_pay)) ///
   ( vaccinated_est_min , aseq(No Reminders Condition) $min_inc_opts keep(treat_min) )  ///
  ( intention1_est_min  , aseq(No Reminders: Intention) $min_int_opts keep(treat_min) )  ///
 , nooffsets ylabel(, noticks) coeflabels(, wrap(26))	ciopts(lwidth(*2)) levels(90) swapnames drop(_cons) xline(0, lcolor(gs5) lwidth(medthick)) msize(large) graphregion(color(white)) ///  
		  grid(none) xscale(range(-6 10)) xlabels(-6(1)+10, labsize(medium)) mlabposition(1)  xtitle(Regression estimated impact in percentage points, height(7)) legend(order(2  "Vaccination Uptake" 4 "Vaccination Intentions") position(12) size(medium) region(lcolor(white)) height(7)) 

graph export "$export/coefficients.pdf", as(pdf) replace
graph export "$export/coefficients.emf", as(tif) replace
graph export "$export/coefficients.png", as(png) replace



* Figure 3 (labels were made nicer in adobe acrobat)
preserve
replace clicked = clicked*100

est clear

reg		clicked $treatments  $pap_contr $sample & treat_min == 0, robust
estimates store vaccinated_est_pay


reg		clicked treat_pay nudge $pap_contr $sample & treat_min == 0, robust
estimates store vaccinated_est_nudge

reg		intention1 $treatments $pap_contr $sample  & treat_min == 0, robust
estimates store intention1_est_pay 

foreach i in soc arg info  {
reg		clicked $treatments  $pap_contr $sample & treat_min == 0, robust
estimates store vaccinated_est_`i'

}
restore


graph set window fontface "Arial"

coefplot ( vaccinated_est_pay  , aseq(Incentives Condition) $inc_opts keep(treat_pay) )  ///
 ( vaccinated_est_nudge  , aseq(All Nudge Conditions) $nudge1_inc_opts keep(nudge))  ///
  (intention1_est_pay  , aseq(NOT 1) $none_opts keep(treat_pay) ) ///
 ( vaccinated_est_soc , aseq(Social Impact Condition) $nudge_inc_opts keep(treat_soc))  ///
   ( vaccinated_est_arg  , aseq(Argument Condition) $nudge_inc_opts keep(treat_arg) )  ///
   ( vaccinated_est_info  , aseq(Information Condition) $nudge_inc_opts keep(treat_info))  ///
   , nooffsets ylabel(, noticks) coeflabels(, wrap(26))	ciopts(lwidth(*2)) levels(90) swapnames drop(_cons) xline(0, lcolor(gs5) lwidth(medthick)) msize(large) graphregion(color(white)) ///  
		  grid(none) xscale(range(-6 10)) xlabels(-6(1)+10, labsize(medium)) mlabposition(1)  xtitle(Regression estimated impact in percentage points, height(7)) legend(order(2 "Clicks on the Appointment Link" ) position(12) size(medium) region(lcolor(white)) height(7)) 
	*	  mlabel(cond(@pval<.02, "{bf:***}", cond(@pval<.10, "{bf:**}",  cond(@pval<.20, "{bf:*}", "" )))) 
		  * note("* p < 0.1, ** p < .05, *** p < .01", height(5) pos(6)) 

graph export "$export/coefficients_clicked.pdf", as(pdf) replace
graph export "$export/coefficients_clicked.emf", as(tif) replace
graph export "$export/coefficients_clicked.png", as(png) replace






****** Creating figures and tables for the SM

* Fig S2 Distance to survey rollout

histogram dist_survey_rollout $sample, discrete fcolor(gs11%40) lcolor(gs11%80) percent xtitle("Days Between Vaccination Rollout to Trial Participation", height(7)) xlabel(-40(5)40, valuelabel ) xline(-1, lcolor(black))
graph export "$export/dist_survey_rollout.pdf", as(pdf) replace
graph export "$export/dist_survey_rollout.png", as(png) replace


* Fig S3 Distance to datamerge
histogram dist_datamerge $sample, discrete fcolor(gs11%40) lcolor(gs11%80) percent xtitle("Observed Days Between Trial Participation and Linkage with Admin. Records", height(7)) xlabel(27(5)77, valuelabel ) xline(-1, lcolor(black))
graph export "$export/dist_datamerge.pdf", as(pdf) replace
graph export "$export/dist_datamerge.png", as(png) replace


* Tab S2:
* Dep. Vars
preserve
replace clicked = clicked*100
keep $sample
*
local dep_vars1  vaccinated vacc_dist clicked intention1 intention2_1 intention3 gap1
* Main Independent Vars
local independent_vars treat_pay nudge treat_soc treat_arg treat_info treat_min control
* Covariates
local covariates_ind age female civilstatus_d* ///     
haschildren education_d* occupation_d* mother_d* father_d* income_d*
local preferences falk* 
local covid covid1_1 covid2_1 covid2_2 covid2_3 covid2_4
 estpost sum `dep_vars1' `dep_vars2' `independent_vars' `covariates_ind' `preferences' `covid'
esttab . using "$export\summarystats.tex", replace ///
		prehead("Variable") ///
		refcat(vaccinated "\addlinespace \emph{Behaviors and Intentions}" treat_pay  "\addlinespace \emph{Treatment Assignment}" age "\addlinespace \emph{Sociodemographics}" falk1_1 "\addlinespace \emph{Economic Preferences}"covid1_1 "\addlinespace \emph{COVID-19 Related}", nolabel) ///
		nomtitles ///
		cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(0) label(Min.)) max(fmt(0) label(Max.)) count(fmt(%9.0gc) label(N))") label booktabs nonum gaps noobs f ///
		varlabels(_cons Constant, end("") nolast)
restore
		

* Tab S3 Balance
est clear

preserve
replace income = income/10000

foreach i in age female single haschildren university income foreign unemployed {
	eststo:    		reg		`i'  treat_pay nudge treat_min  $sample, robust
	eststo: reg `i' $treatments $sample, robust
}

restore
esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\balance.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Age} &   \multicolumn{2}{c}{Female} &   \multicolumn{2}{c}{Single} &   \multicolumn{2}{c}{Has childr.}  &   \multicolumn{2}{c}{College}  &   \multicolumn{2}{c}{Income} &   \multicolumn{2}{c}{Immigr.} &   \multicolumn{2}{c}{Unemployed} &     \\ \cmidrule{2-17}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)}&{(11)}&{(12)}&{(13)}&{(14)}&{(15)}&{(16)}\\") ///
				posthead("\midrule \addlinespace") ///
			keep($treatments nudge ) $order ///
							$pvalues 	
				

* Tab S4 on representativity was combined with data from public registry data from SCB (Statistics Sweden)
sum age 
sum female
tab largeregions


* Tab S5 Main treatment effects
estimates clear
eststo:    		reg		$behavior1 treat_pay nudge treat_min $pap_contr $sample, robust
controls
eststo:    		reg		$behavior1 $treatments $pap_contr $sample, robust
controls

eststo:    		reg		$intention1 treat_pay nudge treat_min $pap_contr $sample, robust
controls
eststo:    		reg		$intention1 $treatments $pap_contr $sample, robust
controls

esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\main_results.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake} &   \multicolumn{2}{c}{Vaccination Intentions}  \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)}&{(4)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge ) $order ///
				$pvalues 	///
				stats($stats)
				


* Fig S4 Vaccination uptake by experimental condition
global rcap_opt_main xtitle("")  ylabel(65(5)85,labsize(vlarge) angle(360) labgap(1.5) nogrid)  legend(off) lcolor(gs13) lwidth(medium)

global conf_int level(90)
global twoway_bar_opt  lwidth(none) barw(0.75) graphregion(color(white)) 
global treatment_label xlabel(1 `""{bf:Incentives}" "Condition""' 2 `""{bf:All Nudges}" "Condition""' 0 `""{bf:Control}" "Condition""' 3 `""Social Imp." "Condition""' 4 `""Argument" "Condition""' 5 `""Information" "Condition""' 6 `""No reminders" "Condition""', labsize(small) labgap(4) noticks)


preserve
append using "data_analysis/suppl_data_4.dta", gen(bla)

recode treatment  (5=0) (0=1) (6=2) (1=3) (2=4) (3=5) (4=6) 
$statsby_comm $sample, by(treatment) clear: ci mean vaccinated, $conf_int
gen round_mean = round(mean,0.1)
gen mean_label = string(round_mean, "%2.1f")
replace mean_label = mean_label+"%"
twoway (bar mean treatment if treatment == 0, $twoway_bar_opt fcolor(gs3) fintensity(inten80)) ///
(bar mean treatment if treatment == 1, $twoway_bar_opt  fcolor($incentivecolor) fintensity(inten90)) ///
 (bar mean treatment if treatment == 2, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
(bar mean treatment if treatment == 3, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
 (bar mean treatment if treatment == 4, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
 (bar mean treatment if treatment == 5, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
  (bar mean treatment if treatment == 6, $twoway_bar_opt fcolor($remindercolor) fintensity(inten80)) ///
(scatter round_mean treatment, msymbol(none) mlabel(mean_label) mlabsize(medlarge) mlabgap(25pt) mlabposition(12)) ///
(rcap ub lb treatment, title("{bf:Vaccination Uptake (%)}", size(large) height(8) position(11) color(black)) $rcap_opt_main $treatment_label ) 
graph export "$export/main_effects.pdf", as(pdf) replace
graph export "$export/main_effects.png", as(png) replace
restore



* Figure S5:  Vaccination intentions by experimental condition
global rcap_opt_main xtitle("")  ylabel(75(5)95,labsize(vlarge) angle(360) labgap(1.5) nogrid)  legend(off) lcolor(gs10) lwidth(medium)

global statsby_comm statsby mean=r(mean) ub=r(ub) lb=r(lb) N=r(N)
global conf_int level(90)
global twoway_bar_opt fcolor(gs7) fintensity(inten100) lwidth(none) barw(0.75) graphregion(color(white)) 
global treatment_label xlabel(1 `""{bf:Incentives}" "Condition""' 0 `""{bf:Control}" "Condition""' 2 `""Social Imp." "Condition""' 3 `""Argument" "Condition""' 4 `""Information" "Condition""' 5 `""No reminders" "Condition""', labsize(medsmall) labgap(4) noticks)


preserve
recode treatment (5=0) (0=1) (1=2) (2=3) (3=4) (4=5) 
$statsby_comm $sample, by(treatment) clear: ci mean $intention1, $conf_int
gen round_mean = round(mean,0.1)
gen mean_label = string(round_mean, "%2.1f")
replace mean_label = mean_label+"%"
twoway (bar mean treatment if treatment == 0, $twoway_bar_opt fcolor(gs3) fintensity(inten80)) ///
(bar mean treatment if treatment == 1, $twoway_bar_opt  fcolor(dkgreen) fintensity(inten90)) ///
 (bar mean treatment if treatment == 2, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
(bar mean treatment if treatment == 3, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
 (bar mean treatment if treatment == 4, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
 (bar mean treatment if treatment == 5, $twoway_bar_opt fcolor(gs10) fintensity(inten80)) ///
(scatter round_mean treatment, msymbol(none) mlabel(mean_label) mlabsize(medlarge) mlabgap(25pt) mlabposition(12)) ///
(rcap ub lb treatment, title("{bf:Intended Vaccination Uptake (%), binary}", size(large) height(8) position(11) color(black)) $rcap_opt_main $treatment_label ) 
graph export "$export/main_effects_intention1.pdf", as(pdf) replace
graph export "$export/main_effects_intention1.png", as(png) replace
restore



* Table S6:  Treatment effects using the secondary outcome variables
estimates clear


eststo:    		tobit		vacc_dist_cens $nudge $pap_contr $sample ,  ll(0) ul(30)
controls

	
eststo:    		tobit		vacc_dist_cens $treatments $pap_contr $sample ,  ll(0) ul(30)
controls

	preserve
	replace clicked = clicked * 100

	eststo:    		reg		clicked $nudge $pap_contr $sample & treat_min == 0, robust
	controls

	eststo:    		reg		clicked $treatments  $pap_contr $sample & treat_min == 0, robust
	controls

	restore

	eststo:    		reg		intention2_1 $nudge    $pap_contr $sample, robust
	controls
	
	eststo:    		reg		intention2_1 $treatments $pap_contr $sample, robust
	controls


	eststo:    		reg		intention3 $nudge $pap_contr $pap_contr $sample, robust
	controls  
	
	eststo:    		reg		intention3 $treatments $pap_contr $sample, robust
	controls

eststo:    		reg		gap1 $nudge $pap_contr $sample , robust
controls

eststo:    		reg		gap1 $treatments $pap_contr $sample , robust
controls

esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\Intention_behavior_results.tex", collabels(none) nomtitles nonumbers replace f ///
label booktabs b(2) se(2) alignment(c c) ///
					prehead("Dependent Variable &   \multicolumn{2}{c}{Days to} & \multicolumn{2}{c}{Appointment}  & \multicolumn{4}{c}{Intention Measure:} & \multicolumn{2}{c}{Intention-behavior} \\ & \multicolumn{2}{c}{Vaccination} &   \multicolumn{2}{c}{Link Click}     &   \multicolumn{2}{c}{Continuous} &   \multicolumn{2}{c}{Time} & \multicolumn{2}{c}{Gap} \\ & &  & \multicolumn{2}{c}{Yes=100 or No=0} &  \multicolumn{2}{c}{0 to 100\%} &   \multicolumn{2}{c}{2 to 10}  &   \multicolumn{2}{c}{Yes=100 or No=0} \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)} \\") ///				
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge ) $order ///
				$pvalues 	///
				stats($stats)



* Figure S6:  Link clicking by experimental condition
global rcap_opt_main xtitle("")  ylabel(0(2)14,labsize(vlarge) angle(360) labgap(1.5) nogrid)  legend(off) lcolor(gs12) lwidth(medium)


global statsby_comm statsby mean=r(mean) ub=r(ub) lb=r(lb) N=r(N)
global conf_int level(90)
global twoway_bar_opt  lwidth(none) barw(0.75) graphregion(color(white)) 
global treatment_label xlabel(1 `""{bf:Incentives}" "Condition""' 2 `""{bf:All Nudges}" "Condition""' 0 `""{bf:Control}" "Condition""' 3 `""Social Imp." "Condition""' 4 `""Argument" "Condition""' 5 `""Information" "Condition""', labsize(small) labgap(4) noticks)


preserve
append using "data_analysis/suppl_data_4.dta", gen(bla)
keep if treatment != 4
replace clicked = clicked * 100
recode treatment  (5=0) (0=1) (6=2) (1=3) (2=4) (3=5) (4=6) 
$statsby_comm $sample, by(treatment) clear: ci mean clicked, $conf_int
gen round_mean = round(mean,0.1)
gen mean_label = string(round_mean, "%2.1f")
replace mean_label = mean_label+"%"
twoway (bar mean treatment if treatment == 0, $twoway_bar_opt fcolor(gs3) fintensity(inten80)) ///
(bar mean treatment if treatment == 1, $twoway_bar_opt  fcolor($incentivecolor) fintensity(inten90)) ///
 (bar mean treatment if treatment == 2, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
(bar mean treatment if treatment == 3, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
 (bar mean treatment if treatment == 4, $twoway_bar_opt fcolor($nudgecolor) fintensity(inten80)) ///
  (bar mean treatment if treatment == 5, $twoway_bar_opt fcolor($remindercolor) fintensity(inten80)) ///
(scatter round_mean treatment, msymbol(none) mlabel(mean_label) mlabsize(medlarge) mlabgap(25pt) mlabposition(12)) ///
(rcap ub lb treatment, title("{bf:Appointment Link Click (%)}", size(large) height(8) position(11) color(black)) $rcap_opt_main $treatment_label ) 
graph export "$export/main_effects_clicked.pdf", as(pdf) replace
graph export "$export/main_effects_clicked.png", as(png) replace
restore




* Table S7:  Treatment effects on vaccination uptake by different time windows
foreach j in 50 {

estimates clear


foreach i in  10 20 30 40 50   {

		eststo: reg		vaccinated_`i'd $nudge $pap_contr $sample  & dist_datamerge > `j' , robust
		controls

		eststo: reg		vaccinated_`i'd $treatments $pap_contr $sample  & dist_datamerge > `j' , robust
		controls

}
esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\differenttimes_results_observed`j'days.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccinated} &   \multicolumn{2}{c}{Vaccinated}  &      \multicolumn{2}{c}{Vaccinated } & \multicolumn{2}{c}{Vaccinated } & \multicolumn{2}{c}{Vaccinated } &   \\ &   \multicolumn{2}{c}{in 10 Days} &   \multicolumn{2}{c}{in 20 Days} &\multicolumn{2}{c}{in 30 Days}  &    \multicolumn{2}{c}{in 40 Days}  &    \multicolumn{2}{c}{in 50 Days}  &    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)} &{(7)}&{(8)}&{(9)}&{(10)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)					
}		
		
	
* Figure  S7:   Proportion  of  participants  who  got  the  vaccine  per  day  after  the trial
preserve
use "data_analysis/suppl_data_3.dta", clear

twoway ///
(tsline vaccinated_now if treatment == 1, lcolor($nudgecolor))  ///
(tsline vaccinated_now if treatment == 2, lcolor($nudgecolor)) ///
(tsline vaccinated_now if treatment == 3, lcolor($nudgecolor)) ///
(tsline vaccinated_now if treatment == 4, lcolor($remindercolor)) ///  
(tsline vaccinated_now if treatment == 6, lcolor($nudgecolor) lwidth(medthick)) ///
(tsline vaccinated_now if treatment == 5, lcolor(gs3) lwidth(medthick)) ///
(tsline vaccinated_now if treatment == 0, lcolor($incentivecolor) lwidth(medthick) ylabel(0(10)80,labsize(medlarge) angle(360) labgap(1.5) nogrid) xlabel(0(5)30, labsize(medlarge) labgap(1.5)) xtitle("Distance in Days to Survey", size(medlarge) height(+7)) ytitle("Proportion of Participants", size(medlarge)) ) , legend(label(7 "Incentives Cond.") label(5 "All Nudges") label(6 "Control Cond.") label(1 "Social Impact Cond.") label(2 "Argument Cond.") label(3 "Information Cond.") label(4 "No reminders Cond.") ring(0) position(4) bmargin(medium) size("*0.6")) 
graph export "$export/curves.pdf", as(pdf) replace
graph export "$export/curves.png", as(png) replace
restore



* Table S8:  Treatment effects on vaccination uptake, different definitions
estimates clear

eststo:    		reg		vaccinated $nudge $pap_contr $sample, robust
controls
eststo:    		reg		vaccinated $treatments $pap_contr $sample, robust
controls

eststo:    		reg		vaccinated_rollout $nudge $pap_contr $sample, robust
controls

eststo:    		reg		vaccinated_rollout $treatments $pap_contr $sample, robust
controls

eststo:    		reg		vaccinated_incentives $nudge $pap_contr $sample, robust
controls

eststo:    		reg		vaccinated_incentives $treatments $pap_contr $sample, robust
controls

esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\main_results_defvaccinated.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{6}{c}{Vaccination } &   \\ &   \multicolumn{2}{c}{Uptake} &   \multicolumn{2}{c}{Uptake} &     \multicolumn{2}{c}{Uptake } \\ &   \multicolumn{2}{c}{} &   \multicolumn{2}{c}{Availability} &     \multicolumn{2}{c}{Survey/Avail.} \\\cmidrule{2-7}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)		
				


* Table S9:  Comparing incentives to nudges
est clear

eststo: reg vaccinated treat_pay $pap_contr $sample & treatment != 4 & treatment != 5, rob

controls

eststo: reg intention1 treat_pay $pap_contr $sample & treatment != 4 & treatment != 5, rob

controls

preserve

replace clicked = clicked*100
eststo: reg clicked treat_pay $pap_contr $sample & treatment != 4 & treatment != 5, rob

controls

restore

esttab,    $esttab_opt  ///
			keep(treat_pay) ///
						noconst label  /// 
						$pvalues
esttab using "$export\incentives_vs_others.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{1}{c}{Vaccination Uptake} &   \multicolumn{1}{c}{Vaccination Intentions}  &   \multicolumn{1}{c}{App. Link Click}  \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep(treat_pay) order($emotions) ///
				$pvalues 	///
				stats($stats)



* Table S10:   Treatment  effects  controlling  for  each  age-region  interaction.		
estimates clear
eststo:    		reg		$behavior1 $nudge  i.age##i.region $sample, robust
estadd local age_region_fe "yes"	


eststo:    		reg		$behavior1 $treatments  i.age##i.region $sample, robust
estadd local age_region_fe "yes"	

eststo:    		reg		$behavior1 $nudge $pap_contr i.age##i.region $sample, robust
controls_ageregion


eststo:    		reg		$behavior1 $treatments $pap_contr i.age##i.region $sample, robust
controls_ageregion


eststo:    		reg		$intention1 $nudge i.age##i.region $sample, robust
estadd local age_region_fe "yes"

eststo:    		reg		$intention1 $treatments i.age##i.region $sample, robust
estadd local age_region_fe "yes"	

eststo:    		reg		$intention1 $nudge $pap_contr i.age##i.region $sample , robust
controls_ageregion

eststo:    		reg		$intention1 $treatments $pap_contr i.age##i.region $sample , robust
controls_ageregion



esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\eachageregion.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{4}{c}{Vaccination Uptake} &   \multicolumn{4}{c}{Vaccination Intentions}  \\ \cmidrule{2-9}	 &{(1)}&{(2)}&{(3)}&{(4)} &{(5)}&{(6)}&{(7)}&{(8)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats_ageregion)			



* Table S11:  Treatment effects on incentives and all nudges controlling for thetiming of the survey

est clear
  
foreach j in vaccinated intention1 {
	
eststo:    		reg		$behavior1  $nudge  i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	

eststo:    		reg		$behavior1    $nudge   i.age_band i.region i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_fe "yes"	

eststo:    		reg		$behavior1    $nudge   i.region##i.age_band    i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	


eststo:    		reg		$behavior1   $nudge i.week_num  i.region##i.age_band  i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local week_fe "yes"	


eststo:    		reg		$behavior1    $nudge i.week_num##i.region  i.region##i.age_band i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local week_region_fe "yes"	


eststo:    		reg		$behavior1    $nudge i.week_num##i.age  i.region##i.age_band i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local age_week_fe "yes"	

}

esttab using "$export\main_results_fixedeffects_nudge.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{6}{c}{Vaccination Uptake} &   \multicolumn{6}{c}{Vaccination Intentions}  \\ \cmidrule{2-13}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)}&{(11)}&{(12)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($nudge) order($nudge) ///
				$pvalues 	///
				stats(controls age_fe age_region_fe week_fe week_region_fe age_week_fe N , fmt(0 0 0 0 0 0 %9.0gc 2) labels("Controls incl. Gender" "Age FE" "Age x Region FE" "Week FE" "Week x Region FE" "Age x Week FE"  `"\midrule \midrule Observations"'))							
				

* Table S12:  Treatment effects on all conditions controlling for the timing of thesurvey				
est clear
  
foreach j in vaccinated intention1 {
	
eststo:    		reg		$behavior1  $treatments  i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	

eststo:    		reg		$behavior1   $treatments   i.age_band i.region i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_fe "yes"	

eststo:    		reg		$behavior1   $treatments   i.region##i.age_band    i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	


eststo:    		reg		$behavior1   $treatments i.week_num  i.region##i.age_band  i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local week_fe "yes"	


eststo:    		reg		$behavior1   $treatments i.week_num##i.region  i.region##i.age_band i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local week_region_fe "yes"	


eststo:    		reg		$behavior1   $treatments i.week_num##i.age  i.region##i.age_band i.age_band i.female i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local controls "yes"	
estadd local age_region_fe "yes"	
estadd local age_week_fe "yes"	

}

esttab using "$export\main_results_fixedeffects.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{6}{c}{Vaccination Uptake} &   \multicolumn{6}{c}{Vaccination Intentions}  \\ \cmidrule{2-13}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)}&{(11)}&{(12)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments) order($emotions) ///
				$pvalues 	///
				stats(controls age_fe age_region_fe week_fe week_region_fe age_week_fe N , fmt(0 0 0 0 0 0 %9.0gc 2) labels("Controls incl. Gender" "Age FE" "Age x Region FE" "Week FE" "Week x Region FE" "Age x Week FE"  `"\midrule \midrule Observations"'))					
				


				
				
* Table S13:  Treatment effects on incentives and all nudges including differentsets of controls
est clear
  
	
eststo:    		reg		$behavior1 $nudge   if intention1 < . & already_vacced == 0, robust

eststo:    		reg		$behavior1   $nudge  i.region##i.age_band  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	

eststo:    		reg		$behavior1   $nudge  i.region##i.age_band i.female  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 


eststo:    		reg		$behavior1 $nudge i.region##i.age_band i.female i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0 , robust 
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local ses "yes" 

eststo:    		reg		$behavior1  $nudge i.female i.age_band##i.region i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"

eststo:    		reg		$behavior1 $nudge i.female i.age_band##i.region i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income   if intention1 < . & already_vacced == 0, robust

estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"
estadd local covid "yes"



eststo:    		reg		intention1 $nudge  if intention1 < . & already_vacced == 0, robust

eststo:    		reg		intention1    $nudge   i.region##i.age_band if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	

eststo:    		reg		intention1    $nudge  i.region##i.age_band i.female if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 


eststo:    		reg		intention1  $nudge  i.region##i.age_band i.female i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0 , robust 
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes" 

eststo:    		reg		intention1  $nudge i.female i.age_band##i.region i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"

eststo:    		reg		intention1  $nudge i.female i.age_band##i.region i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust

estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"
estadd local covid "yes"

esttab using "$export\main_results_controls_nudge.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{6}{c}{Vaccination Uptake} &   \multicolumn{6}{c}{Vaccination Intentions}  \\ \cmidrule{2-13}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)}&{(11)}&{(12)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($nudge) order($nudge) ///
				$pvalues 	///
				stats(age_region_fe gender_fe sest civil covid  N , fmt(0 0 0 0 0 %9.0gc) labels("Age x Region FE" "Gender" "Socioeconomic Status" "Family" "COVID-19 Risk-group"   `"\midrule \midrule Observations"'))	



* Table S14:  Treatment effects on all conditions including different sets of controls

est clear
  	
eststo:    		reg		$behavior1  $treatments   if intention1 < . & already_vacced == 0, robust

eststo:    		reg		$behavior1   $treatments   i.region##i.age_band  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	

eststo:    		reg		$behavior1   $treatments   i.region##i.age_band i.female  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 


eststo:    		reg		$behavior1 $treatments  i.region##i.age_band i.female i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0 , robust 
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local ses "yes" 

eststo:    		reg		$behavior1  $treatments i.female i.age_band##i.region i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income  if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"

eststo:    		reg		$behavior1 $treatments i.female i.age_band##i.region i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income   if intention1 < . & already_vacced == 0, robust

estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"
estadd local covid "yes"


eststo:    		reg		intention1  $treatments  if intention1 < . & already_vacced == 0, robust

eststo:    		reg		intention1    $treatments   i.region##i.age_band if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	

eststo:    		reg		intention1    $treatments   i.region##i.age_band i.female if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 


eststo:    		reg		intention1  $treatments  i.region##i.age_band i.female i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0 , robust 
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes" 

eststo:    		reg		intention1   $treatments i.female i.age_band##i.region i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust
estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"

eststo:    		reg		intention1  $treatments i.female i.age_band##i.region i.covid1_2 i.civilstatus i.haschildren i.education i.occupation i.mother i.father i.income if intention1 < . & already_vacced == 0, robust

estadd local age_region_fe "yes"	
estadd local gender_fe "yes" 
estadd local sest "yes"
estadd local civil "yes"
estadd local covid "yes"

esttab using "$export\main_results_controls.tex", collabels(none) nomtitles nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{6}{c}{Vaccination Uptake} &   \multicolumn{6}{c}{Vaccination Intentions}  \\ \cmidrule{2-13}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}&{(10)}&{(11)}&{(12)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments) ///
				$pvalues 	///
				stats(age_region_fe gender_fe sest civil covid  N , fmt(0 0 0 0 0 %9.0gc) labels("Age x Region FE" "Gender" "Socioeconomic Status" "Family" "COVID-19 Risk-group"   `"\midrule \midrule Observations"'))	

				
				
				
				
				
				
				
* Table  S15:   Treatment  effects  using  logit  regressions
estimates clear
eststo:    		logit		vaccinated $nudge $pap_contr $sample, robust
controls
eststo:    		logit		vaccinated  $treatments $pap_contr $sample, robust
controls



eststo:    			logit	$intention1 $nudge $pap_contr $sample, robust
controls
eststo:    			logit		$intention1 $treatments $pap_contr $sample   , robust
controls


esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\main_results_logit.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake} &   \multicolumn{2}{c}{Vaccination Intentions} \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)}&{(4)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)				
				


				
* Table S16:  Treatment  effects  with  sample  weights

* Construct weights
preserve 
keep $sample
gen preweigh = 1

gen female_tot= 8286*0.50 if female==0
replace female_tot=8286*0.50 if female==1

** share university studies according to stats sweden = .44095742
gen education_university = education > 4
gen education_university_tot = 8286*0.44095742 if education_university==1
replace education_university_tot = 8286*(1-0.44095742) if education_university==0

** share immigrats according to stats sweden is 40%
gen one_parent_abroad = mother>1 | father>1
gen one_parent_abroad_tot = 8286*0.40 if one_parent_abroad==1
replace one_parent_abroad_tot = 8286*0.60 if one_parent_abroad==0

capture: drop newwt
survwgt rake preweigh, by(female education_university one_parent_abroad) totvars(female_tot education_university_tot one_parent_abroad_tot) generate(newwt)

table female [pw=newwt]

* Estimates
estimates clear
eststo:    		reg		$behavior1 $nudge $pap_contr  [pw=newwt] $sample, robust
controls
eststo:    		reg		$behavior1 $treatments $pap_contr  [pw=newwt] $sample, robust
controls




eststo:    		reg		$intention1 $nudge $pap_contr [pw=newwt] $sample, robust
controls
eststo:    		reg		$intention1 $treatments $pap_contr  [pw=newwt]  $sample, robust
controls




esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\main_results_reweighted.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake} &   \multicolumn{2}{c}{Vaccination Intentions}  \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)}&{(4)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)				
restore				
				

				

* Table S17: Treatment effects including participants who did not finish the survey
preserve
use "data_analysis/suppl_data_9.dta", clear

estimates clear
eststo:    		reg		vaccinated  $nudge $pap_contr if already_vacced == 0, robust
controls
eststo:    		reg		vaccinated  $treatments $pap_contr if already_vacced == 0, robust
controls
esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\results_surveynotcompleted.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake}   \\ \cmidrule{2-5}	 &{(1)}&{(2)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)
restore 

* Table S18: Treatment effects including participants who were already vaccinated
preserve
use "data_analysis/suppl_data_8.dta", clear

estimates clear
eststo:    		reg		vaccinated  $nudge $pap_contr if intention1 < ., robust
controls
eststo:    		reg		vaccinated  $treatments $pap_contr if intention1 < ., robust
controls

eststo:    		reg		$intention1 $nudge $pap_contr if intention1 < ., robust
controls
eststo:    		reg		$intention1 $treatments $pap_contr if intention1 < ., robust
controls


esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\results_keepvacced.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake} &   \multicolumn{2}{c}{Vaccination Intentions}  \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)}&{(4)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)
restore

* Table S19:  Treatment effects including participants who participated more than once
preserve
use "data_analysis/suppl_data_1.dta", clear

estimates clear
eststo:    		reg		vaccinated  $nudge $pap_contr $sample , robust
controls
eststo:    		reg		vaccinated  $treatments $pap_contr $sample , robust
controls




eststo:    		reg		$intention1 $nudge $pap_contr $sample, robust
controls
eststo:    		reg		$intention1 $treatments $pap_contr $sample, robust
controls



esttab,    $esttab_opt  ///
			keep($treatments) ///
						noconst label  /// 
						$pvalues
esttab using "$export\results_keepduplicates.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{2}{c}{Vaccination Uptake} &   \multicolumn{2}{c}{Vaccination Intentions}   \\ \cmidrule{2-5}	 &{(1)}&{(2)}&{(3)}&{(4)} \\") ///
				posthead("\midrule \addlinespace") ///
				keep($treatments nudge) $order ///
				$pvalues 	///
				stats($stats)



* Table S20 Treatment effects including participants who could not be linked

use "data_analysis\suppl_data_2.dta", clear

gen nudge = 1 if treat_soc == 1 | treat_arg == 1 | treat_info == 1
replace nudge = 0 if nudge == . 
label var nudge "All Nudges"

**** Regression table only for intentions also non-matched
estimates clear
	eststo:    		reg		$intention1 $nudge $pap_contr if  intention1 < ., robust
	controls
	eststo:    		reg		$intention1 $treatments $pap_contr if  intention1 < ., robust
	controls




	eststo:    		reg		intention2_1 $nudge $pap_contr if  intention1 < ., robust
	controls
	eststo:    		reg		intention2_1 $treatments $pap_contr if  intention1 < ., robust
	controls



	eststo:    		reg		intention3 $nudge $pap_contr  if  intention1 < ., robust
	controls
	eststo:    		reg		intention3 $treatments $pap_contr  if  intention1 < ., robust
	controls

	
	replace clicked = clicked * 100

	eststo:    		reg		clicked $nudge $pap_contr if treat_min == 0 &  intention1 < ., robust
	controls
	eststo:    		reg		clicked $treatments $pap_contr if treat_min == 0 &  intention1 < ., robust
	controls





	esttab,    $esttab_opt  ///
				keep($treatments) ///
							noconst label  /// 
							$pvalues
	esttab using "$export\intention_results_alsononmatched.tex", collabels(none) nomtitles nonumbers replace f ///
					label booktabs b(2) se(2) alignment(c c) ///
					prehead("Dependent Variable &   \multicolumn{6}{c}{Intention Measure:} & \multicolumn{2}{c}{Appointment} \\ &   \multicolumn{2}{c}{Main}     &   \multicolumn{2}{c}{Continuous} &   \multicolumn{2}{c}{Time} &   \multicolumn{2}{c}{Link Click} \\   & \multicolumn{2}{c}{Yes=100 or No=0} &  \multicolumn{2}{c}{0 to 100\%} &   \multicolumn{2}{c}{1 to 10}  &   \multicolumn{2}{c}{Yes=100 or No=0} \\ \cmidrule{2-9}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)} \\") ///
					posthead("\midrule \addlinespace") ///
					keep($treatments nudge) $order ///
					$pvalues 	///
					stats($stats)
restore
		

* Figure S8 Treatment effects of incentives across sociodemographic groups
est clear

reg		vaccinated $treatments  $pap_contr $sample, robust
estimates store all_sample

reg		vaccinated $treatments  $pap_contr $sample & age < 34, robust
estimates store age_below

reg		vaccinated $treatments $pap_contr $sample   & age >= 34 , robust
estimates store age_above

reg		vaccinated $treatments $pap_contr $sample  & female == 1 , robust
estimates store female

reg		vaccinated $treatments $pap_contr $sample  & female == 0 , robust
estimates store male

reg		vaccinated $treatments $pap_contr $sample  & university == 1 , robust
estimates store college

reg		vaccinated $treatments $pap_contr $sample  & university == 0 , robust
estimates store nocollege

reg		vaccinated $treatments $pap_contr $sample  & income >22500 & foreign == 0 & unemployed == 0 , robust
estimates store highSES

reg		vaccinated $treatments $pap_contr $sample  & income <=22500 | intention1 <. & already_vacced == 0 & foreign == 1 | intention1 <. & already_vacced == 0 & unemployed == 1, robust
estimates store lowSES


 coefplot (all_sample, aseq(All Sample) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
		  (age_below, aseq(Aged Below 34)  mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium))msymbol(circle) )  ///
          (age_above, aseq(Aged at or Above 34) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
         (female, aseq(Female) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
		  (male, aseq(Male) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
			(college,  aseq(College) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
			(nocollege, aseq(No College) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
			(highSES, aseq(High SES) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///						
			(lowSES, aseq(Low SES) mcolor(dkgreen)  ciopts(lcolor(dkgreen) msize(large) lwidth(medium)) msymbol(circle) )  ///
          , nooffsets coeflabels(, wrap(26))	ciopts(lwidth(*2)) keep(treat_pay) levels(90) swapnames drop(_cons) xline(0, lcolor(gs5) lwidth(medium)) msize(large) legend(off) graphregion(color(white)) ///  
		  grid(none) xscale(range(-6 10)) xlabels(-6(1)+10, labsize(medium)) mlabposition(1) title(Impact on Vaccination Uptake (%)) xtitle(Regression estimated impact in percentage points, height(7))
	*	  mlabel(cond(@pval<.02, "{bf:***}", cond(@pval<.10, "{bf:**}",  cond(@pval<.20, "{bf:*}", "" )))) 
		  * note("* p < 0.1, ** p < .05, *** p < .01", height(5) pos(6)) 
graph export "$export\coeffs_splits.pdf", as(pdf) replace
graph export "$export\coeffs_splits.png", as(png) replace



* Table S21:  Heterogeneous treatment effects based on sociodemographics

global sociodem age female single haschildren university income foreign unemployed 


foreach i of global sociodem {
	foreach j of global treatments {
		gen `i'_`j' = `i'*`j'
	}
}



capture program drop stars
program define stars, rclass

	syntax,  se(real) df(real)
	
	local star = ""
	if(ttail(`df',abs(`se'))*2<=0.1) local star = "*" 
	if(ttail(`df',abs(`se'))*2<=0.05) local star = "**"
	if(ttail(`df',abs(`se'))*2<=0.01) local star = "***" 
	if(ttail(`df',abs(`se'))*2>0.1) local star = "{\color{white}{*}}" 
	
	return local star "`star'"

end

preserve
replace income = income/10000
foreach outcome in vaccinated intention1 {



capture: rm "$export\hetero_`outcome'_socio.tex"

file open myfile using "$export\hetero_`outcome'_socio.tex", write

file write myfile "Measure: & \multicolumn{6}{c}{Interaction effect with treatment} \\  &{Baseline}&{Incent.}&{Social Imp.}&{Argument }&{Info.}&{No reminders}  \\  &{Corr.}&{Cond.}&{Cond.}&{Cond.}&{Cond.}&{Cond.}  \\ \midrule " _n

* table design
global noformat %10.2f

foreach var of global sociodem {

if("`var'"=="age") local row1 = "Age"
if("`var'"=="female") local row1 = "Female"
if("`var'"=="single") local row1 = "Single"
if("`var'"=="haschildren") local row1 = "Has children"
if("`var'"=="university") local row1 = "College"
if("`var'"=="income") local row1 = "Income"
if("`var'"=="foreign") local row1 = "Foreign"
if("`var'"=="unemployed") local row1 = "Unemployed"


local row2 = ""   

reg `outcome' `var'_treat_pay `var'_treat_soc `var'_treat_arg `var'_treat_info `var'_treat_min  `var'  $treatments i.region  $sample, rob

local b_`var': display $noformat _b[`var']
local se_`var': display $noformat _se[`var']

local se = _b[`var'] / _se[`var']
local se: display $noformat `se'
local df = e(df_r)
stars, se(`se') df(`df')
local star`var' = r(star)

foreach g of global treatments {
	local b_`var'_`g': display $noformat _b[`var'_`g']
	local se_`var'_`g': display $noformat _se[`var'_`g']
	
local se = _b[`var'_`g'] / _se[`var'_`g']
local se: display $noformat `se'
local df = e(df_r)
stars, se(`se') df(`df')
local star`var'_`g' = r(star)

}

local row1 = "`row1' &       `b_`var''\sym{`star`var''} &       `b_`var'_treat_pay'\sym{`star`var'_treat_pay'} &      `b_`var'_treat_soc'\sym{`star`var'_treat_soc'}  &  `b_`var'_treat_arg'\sym{`star`var'_treat_arg'} &      `b_`var'_treat_info'\sym{`star`var'_treat_info'} &     `b_`var'_treat_min'\sym{`star`var'_treat_min'} "
local row2 = "`row2'&        (`se_`var'') &        (`se_`var'_treat_pay')  &  (`se_`var'_treat_soc')  &  (`se_`var'_treat_arg') &      (`se_`var'_treat_info') &     (`se_`var'_treat_min') "

file write myfile "`row1' \\" _n
file write myfile "`row2' \\" _n
}

file write myfile " \midrule " _n
file write myfile "Region FE   	 & yes &           yes         &           yes         &           yes         &           yes                &           yes            \\ " _n
file close myfile

}
restore


* Table S22:  Heterogeneous treatment effects based on economic preferences, personality traits, and COVID-19 related variables
* 
global pref_covid falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4 covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2

foreach i of global pref_covid {
	foreach j of global treatments {
		gen `i'_`j' = `i'*`j'
	}
}

preserve


foreach outcome in vaccinated intention1 {


capture: rm "$export\hetero_`outcome'.tex"

file open myfile using "$export\hetero_`outcome'.tex", write

file write myfile "Measure: & \multicolumn{6}{c}{Interaction effect with treatment} \\  &{Baseline}&{Incent.}&{Social Imp.}&{Argument }&{Info.}&{No reminders}  \\  &{Corr.}&{Cond.}&{Cond.}&{Cond.}&{Cond.}&{Cond.}  \\ \midrule " _n

* table design
global noformat %10.2f

foreach var of global pref_covid {

if("`var'"=="falk1_1") local row1 = "Altruism"
if("`var'"=="falk1_2") local row1 = "Risk-affinity"
if("`var'"=="falk1_3") local row1 = "Patience"
if("`var'"=="falk2_1") local row1 = "Reciprocity"
if("`var'"=="falk2_2") local row1 = "Trust"
if("`var'"=="falk2_3") local row1 = "Procrastination"
if("`var'"=="falk2_4") local row1 = "Norm-following"
if("`var'"=="covid2_1") local row1 = "COVID-19 vaccines are safe"
if("`var'"=="covid2_2") local row1 = "Vaccines cause disease"
if("`var'"=="covid2_3") local row1 = "Worries side effects COVID-19 vaccines"
if("`var'"=="covid2_4") local row1 = "Afraid of needles"
if("`var'"=="covid1_1") local row1 = "Ever tested positive for COVID-19"
if("`var'"=="covid1_2") local row1 = "COVID-19 risk group"

local row2 = ""   

reg `outcome' `var'_treat_pay `var'_treat_soc `var'_treat_arg `var'_treat_info `var'_treat_min  `var'  $treatments $pap_contr  $sample, rob

local b_`var': display $noformat _b[`var']
local se_`var': display $noformat _se[`var']

local se = _b[`var'] / _se[`var']
local se: display $noformat `se'
local df = e(df_r)
stars, se(`se') df(`df')
local star`var' = r(star)

foreach g of global treatments {
	local b_`var'_`g': display $noformat _b[`var'_`g']
	local se_`var'_`g': display $noformat _se[`var'_`g']
	
local se = _b[`var'_`g'] / _se[`var'_`g']
local se: display $noformat `se'
local df = e(df_r)
stars, se(`se') df(`df')
local star`var'_`g' = r(star)

}

local row1 = "`row1' &       `b_`var''\sym{`star`var''} &       `b_`var'_treat_pay'\sym{`star`var'_treat_pay'} &      `b_`var'_treat_soc'\sym{`star`var'_treat_soc'}  &  `b_`var'_treat_arg'\sym{`star`var'_treat_arg'} &      `b_`var'_treat_info'\sym{`star`var'_treat_info'} &     `b_`var'_treat_min'\sym{`star`var'_treat_min'} "
local row2 = "`row2'&        (`se_`var'') &        (`se_`var'_treat_pay')  &  (`se_`var'_treat_soc')  &  (`se_`var'_treat_arg') &      (`se_`var'_treat_info') &     (`se_`var'_treat_min') "

file write myfile "`row1' \\" _n
file write myfile "`row2' \\" _n
}

file write myfile " \midrule " _n
file write myfile "Age x Region FE   	 & yes &           yes         &           yes         &           yes         &           yes                &           yes            \\ " _n
file write myfile " Controls    							 &    yes  &           yes         &           yes         &           yes         &           yes                &           yes             \\ " _n
file close myfile

}
*
restore




*** Tables S23 to S28: Predictors based on sociodemographics, economic preferences, and COVID-19 related variables


**** Economic preferences and vaccination uptake
preserve
keep  $sample
 
estimates clear

foreach i in falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4 {
	
	eststo:    		reg		$behavior1 `i' $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg		vaccinated falk1_1 falk1_2 falk1_3 $pap_contr i.treat_min  $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
eststo:    		reg		vaccinated  falk2_1 falk2_2 falk2_3 falk2_4 $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls

eststo:    		reg		vaccinated  falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4 $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls

esttab,    $esttab_opt  ///
			keep( falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_pref_vaccinated.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Vaccination Uptake}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)} &{(7)}&{(8)}&{(9)}&{(10)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep( falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4) order($emotions) ///
				$pvalues 	///
				stats($stats)				
				
				
				

**** Economic preferences and the intention-behavior gap
estimates clear

foreach i in falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4 {
	
	eststo:    		reg		gap1 `i' $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg		gap1  falk1_1 falk1_2 falk1_3 $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
eststo:    		reg		gap1   falk2_1 falk2_2 falk2_3 falk2_4 $pap_contr  i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls

eststo:    		reg		gap1   falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4 $pap_contr  i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls

esttab,    $esttab_opt  ///
			keep( falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_pref_intentiongap1.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Intention-Behavior Gap}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)} &{(7)}&{(8)}&{(9)}&{(10)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep( falk1_1 falk1_2 falk1_3 falk2_1 falk2_2 falk2_3 falk2_4) order($emotions) ///
				$pvalues 	///
				stats($stats)					
				
		
		
		
		
**** COVID-19 related variables and vaccination uptake
estimates clear

foreach i in covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2 {
	
	eststo:    		reg		vaccinated `i'  $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg			vaccinated  covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2 $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
esttab,    $esttab_opt  ///
			keep( covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_covid_vaccinated.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Vaccination Uptake}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep( covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2) order(covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2) ///
				$pvalues 	///
				stats($stats)										
		
		
**** COVID-19 related variables and the intention-behavior gap	
estimates clear

foreach i in covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2  {
	
	eststo:    		reg		gap1 `i' $pap_contr i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg		gap1  covid2_1 covid2_2 covid2_3 covid2_4  covid1_1 covid1_2  i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
esttab,    $esttab_opt  ///
			keep( covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2 ) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_covid_gap1.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Intention-Behavior Gap}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep( covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2) order(covid2_1 covid2_2 covid2_3 covid2_4 covid1_1 covid1_2) ///
				$pvalues 	///
				stats($stats)										
		
		
		
		
				
**** Sociodemographics and vaccination uptake
replace income = income / 10000


estimates clear

foreach i of global sociodem {
	
	eststo:    		reg			vaccinated `i'  i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg			vaccinated  $sociodem i.treat_min  $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
esttab,    $esttab_opt  ///
			keep( $sociodem) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_socio_vaccinated.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Vaccination Uptake}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep($sociodem) order($sociodem) ///
				$pvalues 	///
				stats($stats)									
		
				
				
**** Sociodemographics and the intention-behavior gap
estimates clear

foreach i of global sociodem {
	
	eststo:    		reg		gap1 `i' i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
	controls
	
}

eststo:    		reg		gap1  $sociodem  i.treat_min $sample & treatment == 4 | intention1 <. & already_vacced == 0 & treatment == 5, robust
controls
	
esttab,    $esttab_opt  ///
			keep( $sociodem) ///
						noconst label  /// 
						$pvalues
esttab using "$export\corr_socio_gap1.tex", collabels(none) nomtitles nonumbers replace f ///
				label booktabs b(2) se(2) alignment(c c) ///
				prehead("Dependent Variable &   \multicolumn{10}{c}{Intention-Behavior Gap}    \\ \cmidrule{2-11}	 &{(1)}&{(2)}&{(3)}&{(4)}&{(5)}&{(6)}&{(7)}&{(8)}&{(9)}\\") ///
				posthead("\midrule \addlinespace") ///
				keep($sociodem) order($sociodem) ///
				$pvalues 	///
				stats($stats)							
				
restore



				
				
**** Figures S9 and S10: Beliefs about COVID-19 vaccines
histogram belief_prot_death  $sample, discrete fcolor(gs11%40) lcolor(gs11%80) percent xtitle("Beliefs about the protection of vaccination vs. death", height(7)) xlabel(0(1)9, valuelabel angle(20)) xline(9) 
graph export "$export/dist_belief_prot.pdf", as(pdf) replace
graph export "$export/dist_belief_prot.png", as(png) replace

histogram  belief_cause_death   $sample, discrete fcolor(gs11%40) lcolor(gs11%80) percent xtitle("Beliefs about the number of deaths because of vaccination", height(7)) xlabel(0(1)6, valuelabel angle(20)) xline(0)
graph export "$export/dist_belief_cause.pdf", as(pdf) replace
graph export "$export/dist_belief_cause.png", as(png) replace


**** Figures S11 and S12: Expert predictions vs. actual impacts
use "data_analysis/suppl_data_7.dta", replace

preserve

foreach i in behav_arg behav_inc behav_info behav_min behav_social {
	egen `i'_mean = mean(`i'_1)
}

keep behav_arg_mean behav_inc_mean behav_info_mean behav_min_mean behav_social_mean
gen id = _n
keep if id == 1	

rename behav_inc_mean behav_1
rename behav_social_mean behav_2		
rename behav_arg_mean behav_3		
rename behav_info_mean behav_4		
rename behav_min_mean behav_5		

reshape long behav_, i(id) j(treat) 

rename treat treatment			
drop id

merge 1:1 treatment using "data_analysis/suppl_data_5"
keep treatment mean behav_
gen contr = mean if treatment == 0
egen contr_mean = min(contr)	
drop contr

rename behav_ predicted_effects
drop if treatment == 0

gen actual_effects = mean 

replace actual_effects = round(actual_effects, 0.1)
replace predicted_effects = round(predicted_effects, 0.1)

label define treatment1 1 "Incentives Cond." 2 "Social Imp. Cond." 3 "Argument Cond." 4 "Information Cond." 5 "No reminders Cond.", replace
label value treatment treatment1

graph hbar actual_effects predicted_effects, over(treatment) title("Actual or predicted impact of condition in percentage points", size(medium) ) legend(label(1 "Actual estimates") label(2 "Expert predictions")) ylabel(-2(1)5)

graph export "$export/predictions.pdf", as(pdf) replace
graph export "$export/predictions.png", as(png) replace
restore

preserve

foreach i in int_arg int_inc int_inf int_min int_socialbenefit {
	egen `i'_mean = mean(`i'_1)
}

keep int_*
gen id = _n
keep if id == 1	

rename int_inc_mean int_1
rename int_socialbenefit_mean int_2		
rename int_arg_mean int_3		
rename int_inf_mean int_4		
rename int_min_mean int_5		

reshape long int_, i(id) j(treat) 

rename treat treatment			
drop id

merge 1:1 treatment using "data_analysis/suppl_data_6"	
keep treatment mean int_
gen contr = mean if treatment == 0
egen contr_mean = min(contr)	
drop contr

gen actual_effects = mean 
rename int_ predicted_effects
drop if treatment == 0

replace actual_effects = round(actual_effects, 0.1)
replace predicted_effects = round(predicted_effects, 0.1)

label define treatment1 1 "Incentives Cond." 2 "Social Imp. Cond." 3 "Argument Cond." 4 "Information Cond." 5 "No reminders Cond.", replace
label value treatment treatment1

graph hbar actual_effects predicted_effects, over(treatment) title("Actual or predicted impact of condition in percentage points", size(medium) ) legend(label(1 "Actual estimates") label(2 "Expert predictions")) ylabel(-2(1)5)

graph export "$export/predictions_intentions.pdf", as(pdf) replace
graph export "$export/predictions_intentions.png", as(png) replace
restore










